@@ -12,7 +12,10 @@ from .exceptions import NotSupportedInputFile, MaxFileSizeExeeded, Initializatio
 from .utils import colored_network_name, check_all_ps_status
 from .logger import get_logger
 from .stat import Statistic
+from enum import Enum
 
+class ResponseStatus(Enum):
+    CANNOT_DOWNLOAD_URL = 0
 
 class HttpAPI(threading.Thread):
     def __init__(self, funicorn_app, host='0.0.0.0', port=5001, stat=None, threads=40, name='HTTP', timeout=1000, debug=False, register_conn=True):
@@ -99,10 +102,10 @@ class HttpAPI(threading.Thread):
                     img_bytes = request.files['img_bytes']
                     img = convert_bytes_to_img_arr(img_bytes)
                     results = self.funicorn_app.predict_img_bytes(img)
-                    if results is not None:
-                        final_res = results
-                    else:
+                    if results is ResponseStatus.CANNOT_DOWNLOAD_URL:
                         abort(HTTPStatus.BAD_REQUEST)
+                    else:
+                        final_res = results
                     final_res = final_res if len(final_res) != 0 else []
                     resp = jsonify({
                         "error_code": 0,
